pub struct CobsAccumulator<B: DerefMut<Target = [u8]>> { /* private fields */ }Expand description
Basically postcard’s cobs accumulator, but without the deser part
Implementations
Sourceimpl CobsAccumulator<Box<[u8]>>
impl CobsAccumulator<Box<[u8]>>
pub fn new_boxslice(len: usize) -> Self
Sourceimpl<B: DerefMut<Target = [u8]>> CobsAccumulator<B>
impl<B: DerefMut<Target = [u8]>> CobsAccumulator<B>
Sourcepub fn feed_raw<'me, 'input>(
&'me mut self,
input: &'input mut [u8],
) -> FeedResult<'input, 'me>
pub fn feed_raw<'me, 'input>( &'me mut self, input: &'input mut [u8], ) -> FeedResult<'input, 'me>
Appends data to the internal buffer and attempts to deserialize the accumulated data into
T.
This differs from feed, as it allows the T to reference data within the internal buffer, but
mutably borrows the accumulator for the lifetime of the deserialization.
If T does not require the reference, the borrow of self ends at the end of the function.